package com.zj365.health.act

import android.Manifest
import android.content.Intent
import android.view.View
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.xty.base.act.BaseVmAct
import com.xty.common.LogUtils
import com.xty.common.arouter.ARouterUrl
import com.xty.common.arouter.RouteManager
import com.xty.common.util.CommonToastUtils
import com.xty.common.event.BloodFilipOpenSuccessEvent
import com.xty.common.event.OpenOrRenewEvent
import com.xty.common.util.JumpPermissionManagement
import com.xty.common.xqr_code.XQRCodeAct

import com.xuexiang.xqrcode.XQRCode
import com.zj365.health.R
import com.zj365.health.databinding.ActXzhiOpenBinding
import com.zj365.health.vm.BloodFatVm
import com.zj365.health.weight.DialogTip
import org.greenrobot.eventbus.EventBus
import pub.devrel.easypermissions.EasyPermissions

/**
 * 血脂卡片开通
 */
@Route(path = ARouterUrl.XZ_OPEN)
class XZhiOpenAct : BaseVmAct<BloodFatVm>() {

    val binding by lazy { ActXzhiOpenBinding.inflate(layoutInflater) }
    override fun setLayout() = binding.root

    private var isOpen = false
    var userId = ""

    override fun initData() {
        super.initData()
        isDarkBar = true//设置状态栏字体为深色
        intent.extras?.let {
            isOpen = it.getBoolean("isOpen", false)
            userId = it.getString("id").toString()
        }
    }

    override fun initView() {
        super.initView()
        statusBar(binding.title.mView)
        binding.title.mTvTitle.text = if (isOpen) {
            getString(R.string.xz_renew)
        } else {
            getString(R.string.xz_open)
        }

        binding.title.mIvBack.apply {
            this.setOnClickListener {
                finish()
            }
        }

        binding.mConfirm.isSelected = true

        binding.mTvConvert.setOnClickListener(onClickListener)
        binding.mPrivate.setOnClickListener(onClickListener)
        binding.mConfirm.setOnClickListener(onClickListener)
        binding.llScan.setOnClickListener {
            startScan()
        }
    }

    /**
     * 扫码
     */
    private fun startScan() {
        if(EasyPermissions.hasPermissions(this,
                Manifest.permission.CAMERA)){
            XQRCodeAct.start(
                this@XZhiOpenAct,
                XQRCodeAct.QRCODE_AGREEMENT,
                R.style.XQRCodeTheme_Custom
            )
        }else{
            if (EasyPermissions.somePermissionDenied(this,
                    Manifest.permission.CAMERA)){
                DialogTip(
                    this,
                    "中健365需要相机权限,需要打开设置页面么?"
                ) {
                    JumpPermissionManagement.GoToSetting(this@XZhiOpenAct)
                }.show()

            }else{
                DialogTip(
                    this,
                    "中健365需要相机权限，以便您使用扫一扫功能"
                ) {
                    EasyPermissions.requestPermissions(this,"",
                        0x00011,
                        Manifest.permission.CAMERA)
                }.show()
            }


        }
    }

    private val onClickListener = View.OnClickListener {
        when (it.id) {
            //获取兑换码
            R.id.mTvConvert -> {
                bundle.clear()
                RouteManager.goAct(ARouterUrl.XZ_HOW_OPEN)
            }
            //开通须知
            R.id.mPrivate -> {
                binding.mPrivate.isSelected = !binding.mPrivate.isSelected
            }
            //确定兑换
            R.id.mConfirm -> {
                confirm()
            }
        }
    }

    private fun confirm() {
        if (binding.mTvActCode.text.isNullOrEmpty()) {
            CommonToastUtils.showToast("请输入激活码")
            return
        }

        if (!binding.mPrivate.isSelected) {
            CommonToastUtils.showToast("请阅读开通须知")
            return
        }

        mViewModel.renewOpenRequest(
            userId,
            5,
            "EXCHANGE_CODE",
            binding.mTvActCode.text.toString()
        )
    }

    override fun liveObserver() {
        mViewModel.renewOpenData.observe(this) {
            if (null == it.data) {
                LogUtils.e("操作异常！")
                return@observe
            }
            val code = it.code
            if (code != 0) {
                if (isOpen) {
                    CommonToastUtils.showToast("续费失败：${it.msg}")
                } else {
                    CommonToastUtils.showToast("开通失败：${it.msg}")
                }
                return@observe
            } else {
                if (isOpen) {
                    CommonToastUtils.showSucceedToast("续费成功")
                } else {
                    CommonToastUtils.showSucceedToast("开通成功")
                }
                EventBus.getDefault().post(BloodFilipOpenSuccessEvent())
                EventBus.getDefault().post(OpenOrRenewEvent())
                finish()
            }
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode === RESULT_OK) {
            when (requestCode) {
                XQRCodeAct.QRCODE_AGREEMENT -> {
                    when (data!!.getIntExtra(XQRCode.RESULT_TYPE, 0)) {
                        XQRCode.RESULT_SUCCESS -> {
                            try {
                                val result = data.extras!!.getString(XQRCode.RESULT_DATA)
                                LogUtils.d("扫描结果:$result")
                                if (!result.isNullOrEmpty()) {
                                    val gson = Gson()
                                    //设置扫描结果
                                    binding.mTvActCode.setText(result)
                                } else {
                                    CommonToastUtils.showToast("扫码失败,请重试...")
                                }
                            } catch (e: Exception) {
                                LogUtils.e("二维码扫描：$e")
                                CommonToastUtils.showToast("请确认二维码是否正确！")
                            }
                        }

                        XQRCode.RESULT_FAILED -> {
                            LogUtils.d("扫描失败")

                        }
                    }
                }
            }
        }
    }
}